#ifndef _NUNCHUCK_H_
#define _NUNCHUCK_H_

// ------------------------------------------------------------------------------------------------------
// Nunchuck - code the read the intpus from the Nintendo Wii NunChuck
// ------------------------------------------------------------------------------------------------------
//
// The Ninteno Wii Nunchuck is a combination of 2 axis-joystick, 2 pushbuttons, and 3 axis acclerometer
// all sensed and interfaced via the I2C interface. The acclerometer is an ST Microelectronics LIS3L02A 
// MEMS that is capable of 10 bit resolution ( 2g threshold ), while the joystick has 8 bit resolution.
//
// ------------------------------------------------------------------------------------------------------


// Nunchuck status ( this is the structure that is publicaly accessible )

typedef struct 
{
  uint8_t  xStick;          // X axis joystick X value ( -127 to 127 )
  uint8_t  yStick;          // Y axis joystick Y value ( -127 to 127 )
  uint16_t xAccel;          // X axis acceleration ( -1023 to 1023 )
  uint16_t yAccel;          // Y axis acceleration ( -1023 to 1023 )
  uint16_t zAccel;          // Z axis acceleration ( -1023 to 1023 )
  bool     zButton;         // Z button status ( true or false )
  bool     cButton;         // C button status ( true of false )
  
} NunchuckData;
 

// Nunchuck raw data format ( from I2C protocol )

enum
{
   NCStickX  = 0 ,          // joystick X axis position
   NCStickY  = 1 ,          // joystick Y axis position
   NCAccelX  = 2 ,          // acclerometer x axis high 8 bits
   NCAccelY  = 3 ,          // acclerometer y axis high 8 bits
   NCAccelZ  = 4 ,          // acclerometer z axis high 8 bits
   NCButtons = 5 ,          // bit 0   = Z button
                            // bit 1   = C button
                            // bit 2|3 = low 2 bits of X acceleromater
                            // bit 4|5 = low 2 bits of Y accelerometer
                            // bit 6|7 = low 2 bits of Z acclerometer
   NCDataSize               
};

// Nunchuck functions

extern uint8_t        NunchuckBegin();
extern uint8_t        NunchuckUpdate();
extern NunchuckData * NunchuckGet();


#endif // _NUNCHUCK_H_
